APM_DEFAULT_LOGGER_NAME = "apm_api_view"
APM_USE_DATABASE = "default"

APM_REQUEST_SAVE_HEADERS = True
APM_REQUEST_SAVE_QUERY_PARAMETERS = True
APM_REQUEST_SAVE_QUERY_STRING = True

APM_NOTIFY_USING_CELERY = False
APM_NOTIFY_ON_DEBUG_TRUE = False
